@@ -1,7 +1,8 @@
 import enum
-from dataclasses import dataclass
 from numbers import Number
 
+from dataclassy import dataclass
+
 
 @dataclass(frozen=True)
 class Shape:
